@@ -3,15 +3,7 @@ from __future__ import annotations
 import os
 
 from bec_lib.endpoints import MessageEndpoints
-from qtpy.QtCore import (
-    QAbstractAnimation,
-    QEasingCurve,
-    QEvent,
-    QPropertyAnimation,
-    QSize,
-    Qt,
-    QTimer,
-)
+from qtpy.QtCore import QEasingCurve, QEvent, QPropertyAnimation, QSize, Qt, QTimer
 from qtpy.QtGui import QAction, QActionGroup, QIcon
 from qtpy.QtWidgets import (
     QApplication,
@@ -27,19 +19,28 @@ from qtpy.QtWidgets import (
 import bec_widgets
 from bec_widgets.utils import UILoader
 from bec_widgets.utils.bec_widget import BECWidget
-from bec_widgets.utils.colors import apply_theme
+from bec_widgets.utils.colors import apply_theme, set_theme
 from bec_widgets.utils.error_popups import SafeSlot
 from bec_widgets.utils.widget_io import WidgetHierarchy
+from bec_widgets.widgets.containers.main_window.addons.hover_widget import HoverWidget
+from bec_widgets.widgets.containers.main_window.addons.notification_center.notification_banner import (
+    BECNotificationBroker,
+    NotificationCentre,
+    NotificationIndicator,
+)
 from bec_widgets.widgets.containers.main_window.addons.scroll_label import ScrollLabel
 from bec_widgets.widgets.containers.main_window.addons.web_links import BECWebLinksMixin
 from bec_widgets.widgets.progress.scan_progressbar.scan_progressbar import ScanProgressBar
 
 MODULE_PATH = os.path.dirname(bec_widgets.__file__)
 
+# Ensure the application does not use the native menu bar on macOS to be consistent with linux development.
+QApplication.setAttribute(Qt.AA_DontUseNativeMenuBar, True)
+
 
 class BECMainWindow(BECWidget, QMainWindow):
-    RPC = False
-    PLUGIN = False
+    RPC = True
+    PLUGIN = True
     SCAN_PROGRESS_WIDTH = 100  # px
     STATUS_BAR_WIDGETS_EXPIRE_TIME = 60_000  # milliseconds
 
@@ -57,6 +58,14 @@ class BECMainWindow(BECWidget, QMainWindow):
         self.app = QApplication.instance()
         self.status_bar = self.statusBar()
         self.setWindowTitle(window_title)
+
+        # Notification Centre overlay
+        self.notification_centre = NotificationCentre(parent=self)  # Notification layer
+        self.notification_broker = BECNotificationBroker()
+        self._nc_margin = 16
+        self._position_notification_centre()
+
+        # Init ui
         self._init_ui()
         self._connect_to_theme_change()
 
@@ -65,6 +74,34 @@ class BECMainWindow(BECWidget, QMainWindow):
             self.display_client_message, MessageEndpoints.client_info()
         )
 
+    def setCentralWidget(self, widget: QWidget, qt_default: bool = False):  # type: ignore[override]
+        """
+        Re‑implement QMainWindow.setCentralWidget so that the *main content*
+        widget always lives on the lower layer of the stacked layout that
+        hosts our notification overlays.
+
+        Args:
+            widget: The widget that should become the new central content.
+            qt_default: When *True* the call is forwarded to the base class so
+                that Qt behaves exactly as the original implementation (used
+                during __init__ when we first install ``self._full_content``).
+        """
+        super().setCentralWidget(widget)
+        self.notification_centre.raise_()
+        self.statusBar().raise_()
+
+    def resizeEvent(self, event):
+        super().resizeEvent(event)
+        self._position_notification_centre()
+
+    def _position_notification_centre(self):
+        """Keep the notification panel at a fixed margin top-right."""
+        if not hasattr(self, "notification_centre"):
+            return
+        margin = getattr(self, "_nc_margin", 16)  # px
+        nc = self.notification_centre
+        nc.move(self.width() - nc.width() - margin, margin)
+
     ################################################################################
     # MainWindow Elements Initialization
     ################################################################################
@@ -96,33 +133,80 @@ class BECMainWindow(BECWidget, QMainWindow):
         self._add_separator()
 
         # Centre: Client‑info label (stretch=1 so it expands)
-        self._client_info_label = ScrollLabel()
+        self._add_client_info_label()
+
+        # Add scan_progress bar with display logic
+        self._add_scan_progress_bar()
+
+        # Setup NotificationIndicator to bottom right of the status bar
+        self._add_notification_indicator()
+
+    ################################################################################
+    # Notification indicator and Notification Centre helpers
+
+    def _add_notification_indicator(self):
+        """
+        Add the notification indicator to the status bar and hook the signals.
+        """
+        # Add the notification indicator to the status bar
+        self.notification_indicator = NotificationIndicator(self)
+        self.status_bar.addPermanentWidget(self.notification_indicator)
+
+        # Connect the notification broker to the indicator
+        self.notification_centre.counts_updated.connect(self.notification_indicator.update_counts)
+        self.notification_indicator.filter_changed.connect(self.notification_centre.apply_filter)
+        self.notification_indicator.show_all_requested.connect(self.notification_centre.show_all)
+        self.notification_indicator.hide_all_requested.connect(self.notification_centre.hide_all)
+
+    ################################################################################
+    # Client message status bar widget helpers
+
+    def _add_client_info_label(self):
+        """
+        Add a client info label to the status bar.
+        This label will display messages from the BEC dispatcher.
+        """
+
+        # Scroll label for client info in Status Bar
+        self._client_info_label = ScrollLabel(self)
         self._client_info_label.setAlignment(
             Qt.AlignmentFlag.AlignHCenter | Qt.AlignmentFlag.AlignVCenter
         )
-        self.status_bar.addWidget(self._client_info_label, 1)
+        # Full label used in the hover widget
+        self._client_info_label_full = QLabel(self)
+        self._client_info_label_full.setAlignment(
+            Qt.AlignmentFlag.AlignHCenter | Qt.AlignmentFlag.AlignVCenter
+        )
+        # Hover widget to show the full client info label
+        self._client_info_hover = HoverWidget(
+            self, simple=self._client_info_label, full=self._client_info_label_full
+        )
+        self.status_bar.addWidget(self._client_info_hover, 1)
 
         # Timer to automatically clear client messages once they expire
         self._client_info_expire_timer = QTimer(self)
         self._client_info_expire_timer.setSingleShot(True)
         self._client_info_expire_timer.timeout.connect(lambda: self._client_info_label.setText(""))
-
-        # Add scan_progress bar with display logic
-        self._add_scan_progress_bar()
+        self._client_info_expire_timer.timeout.connect(
+            lambda: self._client_info_label_full.setText("")
+        )
 
     ################################################################################
     # Progress‑bar helpers
     def _add_scan_progress_bar(self):
 
-        # --- Progress bar -------------------------------------------------
-        # Scan progress bar minimalistic design setup
-        self._scan_progress_bar = ScanProgressBar(self, one_line_design=True)
-        self._scan_progress_bar.show_elapsed_time = False
-        self._scan_progress_bar.show_remaining_time = False
-        self._scan_progress_bar.show_source_label = False
-        self._scan_progress_bar.progressbar.label_template = ""
-        self._scan_progress_bar.progressbar.setFixedHeight(8)
-        self._scan_progress_bar.progressbar.setFixedWidth(80)
+        # Setting HoverWidget for the scan progress bar - minimal and full version
+        self._scan_progress_bar_simple = ScanProgressBar(self, one_line_design=True)
+        self._scan_progress_bar_simple.show_elapsed_time = False
+        self._scan_progress_bar_simple.show_remaining_time = False
+        self._scan_progress_bar_simple.show_source_label = False
+        self._scan_progress_bar_simple.progressbar.label_template = ""
+        self._scan_progress_bar_simple.progressbar.setFixedHeight(8)
+        self._scan_progress_bar_simple.progressbar.setFixedWidth(80)
+        self._scan_progress_bar_full = ScanProgressBar(self)
+        self._scan_progress_hover = HoverWidget(
+            self, simple=self._scan_progress_bar_simple, full=self._scan_progress_bar_full
+        )
 
         # Bundle the progress bar with a separator
         separator = self._add_separator(separate_object=True)
@@ -133,7 +217,7 @@ class BECMainWindow(BECWidget, QMainWindow):
         self._scan_progress_bar_with_separator.layout.setContentsMargins(0, 0, 0, 0)
         self._scan_progress_bar_with_separator.layout.setSpacing(0)
         self._scan_progress_bar_with_separator.layout.addWidget(separator)
-        self._scan_progress_bar_with_separator.layout.addWidget(self._scan_progress_bar)
+        self._scan_progress_bar_with_separator.layout.addWidget(self._scan_progress_hover)
 
         # Set Size
         self._scan_progress_bar_target_width = self.SCAN_PROGRESS_WIDTH
@@ -152,8 +236,8 @@ class BECMainWindow(BECWidget, QMainWindow):
         self._scan_progress_hide_timer.timeout.connect(self._animate_hide_scan_progress_bar)
 
         # Show / hide behaviour
-        self._scan_progress_bar.progress_started.connect(self._show_scan_progress_bar)
-        self._scan_progress_bar.progress_finished.connect(self._delay_hide_scan_progress_bar)
+        self._scan_progress_bar_simple.progress_started.connect(self._show_scan_progress_bar)
+        self._scan_progress_bar_simple.progress_finished.connect(self._delay_hide_scan_progress_bar)
 
     def _show_scan_progress_bar(self):
         if self._scan_progress_hide_timer.isActive():
@@ -342,10 +426,10 @@ class BECMainWindow(BECWidget, QMainWindow):
             msg(dict): The message to display, should contain:
             meta(dict): Metadata about the message, usually empty.
         """
-        # self._client_info_label.setText("")
         message = msg.get("message", "")
         expiration = msg.get("expire", 0)  # 0 → never expire
         self._client_info_label.setText(message)
+        self._client_info_label_full.setText(message)
 
         # Restart the expiration timer if necessary
         if hasattr(self, "_client_info_expire_timer") and self._client_info_expire_timer.isActive():
@@ -359,12 +443,12 @@ class BECMainWindow(BECWidget, QMainWindow):
     @SafeSlot(str)
     def change_theme(self, theme: str):
         """
-        Change the theme of the application.
+        Change the theme of the application and propagate it to widgets.
 
         Args:
-            theme(str): The theme to apply, either "light" or "dark".
+            theme(str): Either "light" or "dark".
         """
-        apply_theme(theme)
+        set_theme(theme)  # emits theme_updated and applies palette globally
 
     def event(self, event):
         if event.type() == QEvent.Type.StatusTip:
@@ -393,22 +477,33 @@ class BECMainWindow(BECWidget, QMainWindow):
         if hasattr(self, "_scan_progress_hide_timer") and self._scan_progress_hide_timer.isActive():
             self._scan_progress_hide_timer.stop()
 
+        ########################################
         # Status bar widgets cleanup
+
+        # Client info label cleanup
         self._client_info_label.cleanup()
-        self._scan_progress_bar.close()
-        self._scan_progress_bar.deleteLater()
+        self._client_info_hover.close()
+        self._client_info_hover.deleteLater()
+        # Scan progress bar cleanup
+        self._scan_progress_bar_simple.close()
+        self._scan_progress_bar_simple.deleteLater()
+        self._scan_progress_bar_full.close()
+        self._scan_progress_bar_full.deleteLater()
+        self._scan_progress_hover.close()
+        self._scan_progress_hover.deleteLater()
         super().cleanup()
 
 
-class UILaunchWindow(BECMainWindow):
-    RPC = True
+class BECMainWindowNoRPC(BECMainWindow):
+    RPC = False
+    PLUGIN = False
 
 
 if __name__ == "__main__":
     import sys
 
     app = QApplication(sys.argv)
-    main_window = UILaunchWindow()
+    main_window = BECMainWindow()
     main_window.show()
     main_window.resize(800, 600)
     sys.exit(app.exec())
